@@ -5,11 +5,11 @@ use warnings;
 
 use base 'HTML::Widgets::NavMenu::Object';
 
-use base 'Class::Accessor';
-
-__PACKAGE__->mk_accessors(
-    qw(CurrentlyActive expanded hide host role rec_url_type),
-    qw(separator show_always skip subs text title url url_is_abs url_type),
+__PACKAGE__->mk_acc_ref([
+    qw(
+    CurrentlyActive expanded hide host role rec_url_type
+    separator show_always skip subs text title url url_is_abs url_type
+    )]
     );
 
 use HTML::Widgets::NavMenu::ExpandVal;
@@ -23,13 +23,78 @@ HTML::Widgets::NavMenu::Tree::Node - an iterator for HTML.
 For internal use only.
 
 =head1 METHODS
+
+=head2 CurrentlyActive
+
+Internal use.
+
+=head2 expanded
+
+Internal use.
+
+=head2 CurrentlyActive
+
+Internal use.
+
+=head2 hide
+
+Internal use.
+
+=head2 host
+
+Internal use.
+
+=head2 role
+
+Internal use.
+
+=head2 rec_url_type
+
+Internal use.
+
+=head2 separator
+
+Internal use.
+
+=head2 show_always
+
+Internal use.
+
+=head2 skip
+
+Internal use.
+
+=head2 subs
+
+Internal use.
+
+=head2 text
+
+Internal use.
+
+=head2 title
+
+Internal use.
+
+=head2 url
+
+Internal use.
+
+=head2 url_is_abs
+
+Internal use.
+
+=head2 url_type
+
+Internal use.
+
 =cut
 
 sub _init
 {
     my $self = shift;
 
-    $self->set("subs", []);
+    $self->subs([]);
 
     return $self;
 }
@@ -43,8 +108,8 @@ Expands the node.
 sub expand
 {
     my $self = shift;
-    my $v = @_ ? (shift(@_)) : 
-        HTML::Widgets::NavMenu::ExpandVal->new(capture => 1)
+    my $v = @_ ? (shift(@_)) :
+        HTML::Widgets::NavMenu::ExpandVal->new({capture => 1})
         ;
     # Don't set it to something if it's already capture_expanded(),
     # otherwise it can set as a non-capturing expansion.
@@ -73,7 +138,7 @@ sub _process_new_sub
 {
     my $self = shift;
     my $sub = shift;
-    $self->update_based_on_sub($sub);    
+    $self->update_based_on_sub($sub);
 }
 
 =head2 $self->update_based_on_sub
@@ -89,7 +154,7 @@ sub update_based_on_sub
     if (my $expand_val = $sub->expanded())
     {
         $self->expand($expand_val);
-    }    
+    }
 }
 
 =head2 $self->add_sub()
@@ -123,7 +188,7 @@ sub get_nth_sub
 sub _num_subs
 {
     my $self = shift;
-    return scalar(@{$self->{'subs'}});
+    return scalar(@{$self->subs()});
 }
 
 =head2 $self->list_regular_keys()
@@ -167,7 +232,7 @@ sub set_values_from_hash_ref
     {
         if (exists($sub_contents->{$key}))
         {
-            $self->set($key, $sub_contents->{$key});
+            $self->$key($sub_contents->{$key});
         }
     }
 
@@ -175,7 +240,7 @@ sub set_values_from_hash_ref
     {
         if ($sub_contents->{$key})
         {
-            $self->set($key, 1);
+            $self->$key(1);
         }
     }
 }
